# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OutboundFee(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset': 'str',
        'outbound_fee': 'str',
        'fee_withheld_rune': 'str',
        'fee_spent_rune': 'str',
        'surplus_rune': 'str',
        'dynamic_multiplier_basis_points': 'str'
    }

    attribute_map = {
        'asset': 'asset',
        'outbound_fee': 'outbound_fee',
        'fee_withheld_rune': 'fee_withheld_rune',
        'fee_spent_rune': 'fee_spent_rune',
        'surplus_rune': 'surplus_rune',
        'dynamic_multiplier_basis_points': 'dynamic_multiplier_basis_points'
    }

    def __init__(self, asset=None, outbound_fee=None, fee_withheld_rune=None, fee_spent_rune=None, surplus_rune=None, dynamic_multiplier_basis_points=None):  # noqa: E501
        """OutboundFee - a model defined in Swagger"""  # noqa: E501
        self._asset = None
        self._outbound_fee = None
        self._fee_withheld_rune = None
        self._fee_spent_rune = None
        self._surplus_rune = None
        self._dynamic_multiplier_basis_points = None
        self.discriminator = None
        self.asset = asset
        self.outbound_fee = outbound_fee
        if fee_withheld_rune is not None:
            self.fee_withheld_rune = fee_withheld_rune
        if fee_spent_rune is not None:
            self.fee_spent_rune = fee_spent_rune
        if surplus_rune is not None:
            self.surplus_rune = surplus_rune
        if dynamic_multiplier_basis_points is not None:
            self.dynamic_multiplier_basis_points = dynamic_multiplier_basis_points

    @property
    def asset(self):
        """Gets the asset of this OutboundFee.  # noqa: E501

        the asset to display the outbound fee for  # noqa: E501

        :return: The asset of this OutboundFee.  # noqa: E501
        :rtype: str
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """Sets the asset of this OutboundFee.

        the asset to display the outbound fee for  # noqa: E501

        :param asset: The asset of this OutboundFee.  # noqa: E501
        :type: str
        """
        if asset is None:
            raise ValueError("Invalid value for `asset`, must not be `None`")  # noqa: E501

        self._asset = asset

    @property
    def outbound_fee(self):
        """Gets the outbound_fee of this OutboundFee.  # noqa: E501

        the asset's outbound fee, in (1e8-format) units of the asset  # noqa: E501

        :return: The outbound_fee of this OutboundFee.  # noqa: E501
        :rtype: str
        """
        return self._outbound_fee

    @outbound_fee.setter
    def outbound_fee(self, outbound_fee):
        """Sets the outbound_fee of this OutboundFee.

        the asset's outbound fee, in (1e8-format) units of the asset  # noqa: E501

        :param outbound_fee: The outbound_fee of this OutboundFee.  # noqa: E501
        :type: str
        """
        if outbound_fee is None:
            raise ValueError("Invalid value for `outbound_fee`, must not be `None`")  # noqa: E501

        self._outbound_fee = outbound_fee

    @property
    def fee_withheld_rune(self):
        """Gets the fee_withheld_rune of this OutboundFee.  # noqa: E501

        Total RUNE the network has withheld as fees to later cover gas costs for this asset's outbounds  # noqa: E501

        :return: The fee_withheld_rune of this OutboundFee.  # noqa: E501
        :rtype: str
        """
        return self._fee_withheld_rune

    @fee_withheld_rune.setter
    def fee_withheld_rune(self, fee_withheld_rune):
        """Sets the fee_withheld_rune of this OutboundFee.

        Total RUNE the network has withheld as fees to later cover gas costs for this asset's outbounds  # noqa: E501

        :param fee_withheld_rune: The fee_withheld_rune of this OutboundFee.  # noqa: E501
        :type: str
        """

        self._fee_withheld_rune = fee_withheld_rune

    @property
    def fee_spent_rune(self):
        """Gets the fee_spent_rune of this OutboundFee.  # noqa: E501

        Total RUNE the network has spent to reimburse gas costs for this asset's outbounds  # noqa: E501

        :return: The fee_spent_rune of this OutboundFee.  # noqa: E501
        :rtype: str
        """
        return self._fee_spent_rune

    @fee_spent_rune.setter
    def fee_spent_rune(self, fee_spent_rune):
        """Sets the fee_spent_rune of this OutboundFee.

        Total RUNE the network has spent to reimburse gas costs for this asset's outbounds  # noqa: E501

        :param fee_spent_rune: The fee_spent_rune of this OutboundFee.  # noqa: E501
        :type: str
        """

        self._fee_spent_rune = fee_spent_rune

    @property
    def surplus_rune(self):
        """Gets the surplus_rune of this OutboundFee.  # noqa: E501

        amount of RUNE by which the fee_withheld_rune exceeds the fee_spent_rune  # noqa: E501

        :return: The surplus_rune of this OutboundFee.  # noqa: E501
        :rtype: str
        """
        return self._surplus_rune

    @surplus_rune.setter
    def surplus_rune(self, surplus_rune):
        """Sets the surplus_rune of this OutboundFee.

        amount of RUNE by which the fee_withheld_rune exceeds the fee_spent_rune  # noqa: E501

        :param surplus_rune: The surplus_rune of this OutboundFee.  # noqa: E501
        :type: str
        """

        self._surplus_rune = surplus_rune

    @property
    def dynamic_multiplier_basis_points(self):
        """Gets the dynamic_multiplier_basis_points of this OutboundFee.  # noqa: E501

        dynamic multiplier basis points, based on the surplus_rune, affecting the size of the outbound_fee  # noqa: E501

        :return: The dynamic_multiplier_basis_points of this OutboundFee.  # noqa: E501
        :rtype: str
        """
        return self._dynamic_multiplier_basis_points

    @dynamic_multiplier_basis_points.setter
    def dynamic_multiplier_basis_points(self, dynamic_multiplier_basis_points):
        """Sets the dynamic_multiplier_basis_points of this OutboundFee.

        dynamic multiplier basis points, based on the surplus_rune, affecting the size of the outbound_fee  # noqa: E501

        :param dynamic_multiplier_basis_points: The dynamic_multiplier_basis_points of this OutboundFee.  # noqa: E501
        :type: str
        """

        self._dynamic_multiplier_basis_points = dynamic_multiplier_basis_points

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OutboundFee, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OutboundFee):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InboundConfirmationCountedStage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'counting_start_height': 'int',
        'chain': 'str',
        'external_observed_height': 'int',
        'external_confirmation_delay_height': 'int',
        'remaining_confirmation_seconds': 'int',
        'completed': 'bool'
    }

    attribute_map = {
        'counting_start_height': 'counting_start_height',
        'chain': 'chain',
        'external_observed_height': 'external_observed_height',
        'external_confirmation_delay_height': 'external_confirmation_delay_height',
        'remaining_confirmation_seconds': 'remaining_confirmation_seconds',
        'completed': 'completed'
    }

    def __init__(self, counting_start_height=None, chain=None, external_observed_height=None, external_confirmation_delay_height=None, remaining_confirmation_seconds=None, completed=None):  # noqa: E501
        """InboundConfirmationCountedStage - a model defined in Swagger"""  # noqa: E501
        self._counting_start_height = None
        self._chain = None
        self._external_observed_height = None
        self._external_confirmation_delay_height = None
        self._remaining_confirmation_seconds = None
        self._completed = None
        self.discriminator = None
        if counting_start_height is not None:
            self.counting_start_height = counting_start_height
        if chain is not None:
            self.chain = chain
        if external_observed_height is not None:
            self.external_observed_height = external_observed_height
        if external_confirmation_delay_height is not None:
            self.external_confirmation_delay_height = external_confirmation_delay_height
        if remaining_confirmation_seconds is not None:
            self.remaining_confirmation_seconds = remaining_confirmation_seconds
        self.completed = completed

    @property
    def counting_start_height(self):
        """Gets the counting_start_height of this InboundConfirmationCountedStage.  # noqa: E501

        the THORChain block height when confirmation counting began  # noqa: E501

        :return: The counting_start_height of this InboundConfirmationCountedStage.  # noqa: E501
        :rtype: int
        """
        return self._counting_start_height

    @counting_start_height.setter
    def counting_start_height(self, counting_start_height):
        """Sets the counting_start_height of this InboundConfirmationCountedStage.

        the THORChain block height when confirmation counting began  # noqa: E501

        :param counting_start_height: The counting_start_height of this InboundConfirmationCountedStage.  # noqa: E501
        :type: int
        """

        self._counting_start_height = counting_start_height

    @property
    def chain(self):
        """Gets the chain of this InboundConfirmationCountedStage.  # noqa: E501

        the external source chain for which confirmation counting takes place  # noqa: E501

        :return: The chain of this InboundConfirmationCountedStage.  # noqa: E501
        :rtype: str
        """
        return self._chain

    @chain.setter
    def chain(self, chain):
        """Sets the chain of this InboundConfirmationCountedStage.

        the external source chain for which confirmation counting takes place  # noqa: E501

        :param chain: The chain of this InboundConfirmationCountedStage.  # noqa: E501
        :type: str
        """

        self._chain = chain

    @property
    def external_observed_height(self):
        """Gets the external_observed_height of this InboundConfirmationCountedStage.  # noqa: E501

        the block height on the external source chain when the transaction was observed  # noqa: E501

        :return: The external_observed_height of this InboundConfirmationCountedStage.  # noqa: E501
        :rtype: int
        """
        return self._external_observed_height

    @external_observed_height.setter
    def external_observed_height(self, external_observed_height):
        """Sets the external_observed_height of this InboundConfirmationCountedStage.

        the block height on the external source chain when the transaction was observed  # noqa: E501

        :param external_observed_height: The external_observed_height of this InboundConfirmationCountedStage.  # noqa: E501
        :type: int
        """

        self._external_observed_height = external_observed_height

    @property
    def external_confirmation_delay_height(self):
        """Gets the external_confirmation_delay_height of this InboundConfirmationCountedStage.  # noqa: E501

        the block height on the external source chain when confirmation counting will be complete  # noqa: E501

        :return: The external_confirmation_delay_height of this InboundConfirmationCountedStage.  # noqa: E501
        :rtype: int
        """
        return self._external_confirmation_delay_height

    @external_confirmation_delay_height.setter
    def external_confirmation_delay_height(self, external_confirmation_delay_height):
        """Sets the external_confirmation_delay_height of this InboundConfirmationCountedStage.

        the block height on the external source chain when confirmation counting will be complete  # noqa: E501

        :param external_confirmation_delay_height: The external_confirmation_delay_height of this InboundConfirmationCountedStage.  # noqa: E501
        :type: int
        """

        self._external_confirmation_delay_height = external_confirmation_delay_height

    @property
    def remaining_confirmation_seconds(self):
        """Gets the remaining_confirmation_seconds of this InboundConfirmationCountedStage.  # noqa: E501

        the estimated remaining seconds before confirmation counting completes  # noqa: E501

        :return: The remaining_confirmation_seconds of this InboundConfirmationCountedStage.  # noqa: E501
        :rtype: int
        """
        return self._remaining_confirmation_seconds

    @remaining_confirmation_seconds.setter
    def remaining_confirmation_seconds(self, remaining_confirmation_seconds):
        """Sets the remaining_confirmation_seconds of this InboundConfirmationCountedStage.

        the estimated remaining seconds before confirmation counting completes  # noqa: E501

        :param remaining_confirmation_seconds: The remaining_confirmation_seconds of this InboundConfirmationCountedStage.  # noqa: E501
        :type: int
        """

        self._remaining_confirmation_seconds = remaining_confirmation_seconds

    @property
    def completed(self):
        """Gets the completed of this InboundConfirmationCountedStage.  # noqa: E501

        returns true if no transaction confirmation counting remains to be done  # noqa: E501

        :return: The completed of this InboundConfirmationCountedStage.  # noqa: E501
        :rtype: bool
        """
        return self._completed

    @completed.setter
    def completed(self, completed):
        """Sets the completed of this InboundConfirmationCountedStage.

        returns true if no transaction confirmation counting remains to be done  # noqa: E501

        :param completed: The completed of this InboundConfirmationCountedStage.  # noqa: E501
        :type: bool
        """
        if completed is None:
            raise ValueError("Invalid value for `completed`, must not be `None`")  # noqa: E501

        self._completed = completed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InboundConfirmationCountedStage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InboundConfirmationCountedStage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from xchainpy2_thornode.api_client import ApiClient


class NetworkApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def ban(self, address, **kwargs):  # noqa: E501
        """ban  # noqa: E501

        Returns the ban status for the provided node address.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ban(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: (required)
        :param int height: optional block height, defaults to current tip
        :return: BanResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.ban_with_http_info(address, **kwargs)  # noqa: E501
        else:
            (data) = self.ban_with_http_info(address, **kwargs)  # noqa: E501
            return data

    def ban_with_http_info(self, address, **kwargs):  # noqa: E501
        """ban  # noqa: E501

        Returns the ban status for the provided node address.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ban_with_http_info(address, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str address: (required)
        :param int height: optional block height, defaults to current tip
        :return: BanResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['address', 'height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ban" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'address' is set
        if ('address' not in params or
                params['address'] is None):
            raise ValueError("Missing the required parameter `address` when calling `ban`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'address' in params:
            path_params['address'] = params['address']  # noqa: E501

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/thorchain/ban/{address}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BanResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def constants(self, **kwargs):  # noqa: E501
        """constants  # noqa: E501

        Returns constant configuration, can be overridden by mimir.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.constants(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: ConstantsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.constants_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.constants_with_http_info(**kwargs)  # noqa: E501
            return data

    def constants_with_http_info(self, **kwargs):  # noqa: E501
        """constants  # noqa: E501

        Returns constant configuration, can be overridden by mimir.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.constants_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: ConstantsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method constants" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/thorchain/constants', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConstantsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def inbound_addresses(self, **kwargs):  # noqa: E501
        """inbound_addresses  # noqa: E501

        Returns the set of asgard addresses that should be used for inbound transactions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.inbound_addresses(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: list[InboundAddress]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.inbound_addresses_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.inbound_addresses_with_http_info(**kwargs)  # noqa: E501
            return data

    def inbound_addresses_with_http_info(self, **kwargs):  # noqa: E501
        """inbound_addresses  # noqa: E501

        Returns the set of asgard addresses that should be used for inbound transactions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.inbound_addresses_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: list[InboundAddress]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method inbound_addresses" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/thorchain/inbound_addresses', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InboundAddress]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lastblock(self, **kwargs):  # noqa: E501
        """lastblock  # noqa: E501

        Returns the last block information for all chains.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lastblock(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: list[LastBlock]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lastblock_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.lastblock_with_http_info(**kwargs)  # noqa: E501
            return data

    def lastblock_with_http_info(self, **kwargs):  # noqa: E501
        """lastblock  # noqa: E501

        Returns the last block information for all chains.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lastblock_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: list[LastBlock]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lastblock" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/thorchain/lastblock', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[LastBlock]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lastblock_chain(self, chain, **kwargs):  # noqa: E501
        """lastblock_chain  # noqa: E501

        Returns the last block information for the provided chain.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lastblock_chain(chain, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain: (required)
        :param int height: optional block height, defaults to current tip
        :return: list[LastBlock]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lastblock_chain_with_http_info(chain, **kwargs)  # noqa: E501
        else:
            (data) = self.lastblock_chain_with_http_info(chain, **kwargs)  # noqa: E501
            return data

    def lastblock_chain_with_http_info(self, chain, **kwargs):  # noqa: E501
        """lastblock_chain  # noqa: E501

        Returns the last block information for the provided chain.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lastblock_chain_with_http_info(chain, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain: (required)
        :param int height: optional block height, defaults to current tip
        :return: list[LastBlock]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['chain', 'height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lastblock_chain" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'chain' is set
        if ('chain' not in params or
                params['chain'] is None):
            raise ValueError("Missing the required parameter `chain` when calling `lastblock_chain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'chain' in params:
            path_params['chain'] = params['chain']  # noqa: E501

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/thorchain/lastblock/{chain}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[LastBlock]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def network(self, **kwargs):  # noqa: E501
        """network  # noqa: E501

        Returns network overview statistics.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.network(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: NetworkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.network_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.network_with_http_info(**kwargs)  # noqa: E501
            return data

    def network_with_http_info(self, **kwargs):  # noqa: E501
        """network  # noqa: E501

        Returns network overview statistics.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.network_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: NetworkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method network" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/thorchain/network', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NetworkResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def outbound_fee_asset(self, asset, **kwargs):  # noqa: E501
        """outbound_fee_asset  # noqa: E501

        Returns the outbound fee information for the provided asset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.outbound_fee_asset(asset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset: (required)
        :param int height: optional block height, defaults to current tip
        :return: list[OutboundFee]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.outbound_fee_asset_with_http_info(asset, **kwargs)  # noqa: E501
        else:
            (data) = self.outbound_fee_asset_with_http_info(asset, **kwargs)  # noqa: E501
            return data

    def outbound_fee_asset_with_http_info(self, asset, **kwargs):  # noqa: E501
        """outbound_fee_asset  # noqa: E501

        Returns the outbound fee information for the provided asset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.outbound_fee_asset_with_http_info(asset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset: (required)
        :param int height: optional block height, defaults to current tip
        :return: list[OutboundFee]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset', 'height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method outbound_fee_asset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset' is set
        if ('asset' not in params or
                params['asset'] is None):
            raise ValueError("Missing the required parameter `asset` when calling `outbound_fee_asset`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset' in params:
            path_params['asset'] = params['asset']  # noqa: E501

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/thorchain/outbound_fee/{asset}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[OutboundFee]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def outbound_fees(self, **kwargs):  # noqa: E501
        """outbound_fees  # noqa: E501

        Returns the last block information for all chains.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.outbound_fees(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: list[OutboundFee]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.outbound_fees_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.outbound_fees_with_http_info(**kwargs)  # noqa: E501
            return data

    def outbound_fees_with_http_info(self, **kwargs):  # noqa: E501
        """outbound_fees  # noqa: E501

        Returns the last block information for all chains.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.outbound_fees_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: list[OutboundFee]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method outbound_fees" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/thorchain/outbound_fees', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[OutboundFee]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def ragnarok(self, **kwargs):  # noqa: E501
        """ragnarok  # noqa: E501

        Returns a boolean indicating whether the chain is in ragnarok.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ragnarok(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.ragnarok_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.ragnarok_with_http_info(**kwargs)  # noqa: E501
            return data

    def ragnarok_with_http_info(self, **kwargs):  # noqa: E501
        """ragnarok  # noqa: E501

        Returns a boolean indicating whether the chain is in ragnarok.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ragnarok_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ragnarok" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/thorchain/ragnarok', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upgrade_proposal(self, name, **kwargs):  # noqa: E501
        """upgrade_proposal  # noqa: E501

        Returns the upgrade proposal for the provided name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upgrade_proposal(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :param int height: optional block height, defaults to current tip
        :return: UpgradeProposal
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upgrade_proposal_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.upgrade_proposal_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def upgrade_proposal_with_http_info(self, name, **kwargs):  # noqa: E501
        """upgrade_proposal  # noqa: E501

        Returns the upgrade proposal for the provided name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upgrade_proposal_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :param int height: optional block height, defaults to current tip
        :return: UpgradeProposal
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upgrade_proposal" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `upgrade_proposal`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/thorchain/upgrade_proposal/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpgradeProposal',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upgrade_proposals(self, **kwargs):  # noqa: E501
        """upgrade_proposals  # noqa: E501

        Returns the current upgrade proposals.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upgrade_proposals(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: list[UpgradeProposal]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upgrade_proposals_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.upgrade_proposals_with_http_info(**kwargs)  # noqa: E501
            return data

    def upgrade_proposals_with_http_info(self, **kwargs):  # noqa: E501
        """upgrade_proposals  # noqa: E501

        Returns the current upgrade proposals.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upgrade_proposals_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: list[UpgradeProposal]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upgrade_proposals" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/thorchain/upgrade_proposals', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[UpgradeProposal]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upgrade_votes(self, name, **kwargs):  # noqa: E501
        """upgrade_votes  # noqa: E501

        Returns the upgrade votes for the provided name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upgrade_votes(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :param int height: optional block height, defaults to current tip
        :return: list[UpgradeVote]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upgrade_votes_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.upgrade_votes_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def upgrade_votes_with_http_info(self, name, **kwargs):  # noqa: E501
        """upgrade_votes  # noqa: E501

        Returns the upgrade votes for the provided name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upgrade_votes_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: (required)
        :param int height: optional block height, defaults to current tip
        :return: list[UpgradeVote]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upgrade_votes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `upgrade_votes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']  # noqa: E501

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/thorchain/upgrade_votes/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[UpgradeVote]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def version(self, **kwargs):  # noqa: E501
        """version  # noqa: E501

        Returns the network's current THORNode version, the network's next THORNode version, and the querier's THORNode version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.version(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: VersionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.version_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.version_with_http_info(**kwargs)  # noqa: E501
            return data

    def version_with_http_info(self, **kwargs):  # noqa: E501
        """version  # noqa: E501

        Returns the network's current THORNode version, the network's next THORNode version, and the querier's THORNode version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.version_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int height: optional block height, defaults to current tip
        :return: VersionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['height']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method version" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/thorchain/version', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='VersionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Borrower(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'owner': 'str',
        'asset': 'str',
        'debt_issued': 'str',
        'debt_repaid': 'str',
        'debt_current': 'str',
        'collateral_deposited': 'str',
        'collateral_withdrawn': 'str',
        'collateral_current': 'str',
        'last_open_height': 'int',
        'last_repay_height': 'int'
    }

    attribute_map = {
        'owner': 'owner',
        'asset': 'asset',
        'debt_issued': 'debt_issued',
        'debt_repaid': 'debt_repaid',
        'debt_current': 'debt_current',
        'collateral_deposited': 'collateral_deposited',
        'collateral_withdrawn': 'collateral_withdrawn',
        'collateral_current': 'collateral_current',
        'last_open_height': 'last_open_height',
        'last_repay_height': 'last_repay_height'
    }

    def __init__(self, owner=None, asset=None, debt_issued=None, debt_repaid=None, debt_current=None, collateral_deposited=None, collateral_withdrawn=None, collateral_current=None, last_open_height=None, last_repay_height=None):  # noqa: E501
        """Borrower - a model defined in Swagger"""  # noqa: E501
        self._owner = None
        self._asset = None
        self._debt_issued = None
        self._debt_repaid = None
        self._debt_current = None
        self._collateral_deposited = None
        self._collateral_withdrawn = None
        self._collateral_current = None
        self._last_open_height = None
        self._last_repay_height = None
        self.discriminator = None
        self.owner = owner
        self.asset = asset
        self.debt_issued = debt_issued
        self.debt_repaid = debt_repaid
        self.debt_current = debt_current
        self.collateral_deposited = collateral_deposited
        self.collateral_withdrawn = collateral_withdrawn
        self.collateral_current = collateral_current
        self.last_open_height = last_open_height
        self.last_repay_height = last_repay_height

    @property
    def owner(self):
        """Gets the owner of this Borrower.  # noqa: E501


        :return: The owner of this Borrower.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this Borrower.


        :param owner: The owner of this Borrower.  # noqa: E501
        :type: str
        """
        if owner is None:
            raise ValueError("Invalid value for `owner`, must not be `None`")  # noqa: E501

        self._owner = owner

    @property
    def asset(self):
        """Gets the asset of this Borrower.  # noqa: E501


        :return: The asset of this Borrower.  # noqa: E501
        :rtype: str
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """Sets the asset of this Borrower.


        :param asset: The asset of this Borrower.  # noqa: E501
        :type: str
        """
        if asset is None:
            raise ValueError("Invalid value for `asset`, must not be `None`")  # noqa: E501

        self._asset = asset

    @property
    def debt_issued(self):
        """Gets the debt_issued of this Borrower.  # noqa: E501


        :return: The debt_issued of this Borrower.  # noqa: E501
        :rtype: str
        """
        return self._debt_issued

    @debt_issued.setter
    def debt_issued(self, debt_issued):
        """Sets the debt_issued of this Borrower.


        :param debt_issued: The debt_issued of this Borrower.  # noqa: E501
        :type: str
        """
        if debt_issued is None:
            raise ValueError("Invalid value for `debt_issued`, must not be `None`")  # noqa: E501

        self._debt_issued = debt_issued

    @property
    def debt_repaid(self):
        """Gets the debt_repaid of this Borrower.  # noqa: E501


        :return: The debt_repaid of this Borrower.  # noqa: E501
        :rtype: str
        """
        return self._debt_repaid

    @debt_repaid.setter
    def debt_repaid(self, debt_repaid):
        """Sets the debt_repaid of this Borrower.


        :param debt_repaid: The debt_repaid of this Borrower.  # noqa: E501
        :type: str
        """
        if debt_repaid is None:
            raise ValueError("Invalid value for `debt_repaid`, must not be `None`")  # noqa: E501

        self._debt_repaid = debt_repaid

    @property
    def debt_current(self):
        """Gets the debt_current of this Borrower.  # noqa: E501


        :return: The debt_current of this Borrower.  # noqa: E501
        :rtype: str
        """
        return self._debt_current

    @debt_current.setter
    def debt_current(self, debt_current):
        """Sets the debt_current of this Borrower.


        :param debt_current: The debt_current of this Borrower.  # noqa: E501
        :type: str
        """
        if debt_current is None:
            raise ValueError("Invalid value for `debt_current`, must not be `None`")  # noqa: E501

        self._debt_current = debt_current

    @property
    def collateral_deposited(self):
        """Gets the collateral_deposited of this Borrower.  # noqa: E501


        :return: The collateral_deposited of this Borrower.  # noqa: E501
        :rtype: str
        """
        return self._collateral_deposited

    @collateral_deposited.setter
    def collateral_deposited(self, collateral_deposited):
        """Sets the collateral_deposited of this Borrower.


        :param collateral_deposited: The collateral_deposited of this Borrower.  # noqa: E501
        :type: str
        """
        if collateral_deposited is None:
            raise ValueError("Invalid value for `collateral_deposited`, must not be `None`")  # noqa: E501

        self._collateral_deposited = collateral_deposited

    @property
    def collateral_withdrawn(self):
        """Gets the collateral_withdrawn of this Borrower.  # noqa: E501


        :return: The collateral_withdrawn of this Borrower.  # noqa: E501
        :rtype: str
        """
        return self._collateral_withdrawn

    @collateral_withdrawn.setter
    def collateral_withdrawn(self, collateral_withdrawn):
        """Sets the collateral_withdrawn of this Borrower.


        :param collateral_withdrawn: The collateral_withdrawn of this Borrower.  # noqa: E501
        :type: str
        """
        if collateral_withdrawn is None:
            raise ValueError("Invalid value for `collateral_withdrawn`, must not be `None`")  # noqa: E501

        self._collateral_withdrawn = collateral_withdrawn

    @property
    def collateral_current(self):
        """Gets the collateral_current of this Borrower.  # noqa: E501


        :return: The collateral_current of this Borrower.  # noqa: E501
        :rtype: str
        """
        return self._collateral_current

    @collateral_current.setter
    def collateral_current(self, collateral_current):
        """Sets the collateral_current of this Borrower.


        :param collateral_current: The collateral_current of this Borrower.  # noqa: E501
        :type: str
        """
        if collateral_current is None:
            raise ValueError("Invalid value for `collateral_current`, must not be `None`")  # noqa: E501

        self._collateral_current = collateral_current

    @property
    def last_open_height(self):
        """Gets the last_open_height of this Borrower.  # noqa: E501


        :return: The last_open_height of this Borrower.  # noqa: E501
        :rtype: int
        """
        return self._last_open_height

    @last_open_height.setter
    def last_open_height(self, last_open_height):
        """Sets the last_open_height of this Borrower.


        :param last_open_height: The last_open_height of this Borrower.  # noqa: E501
        :type: int
        """
        if last_open_height is None:
            raise ValueError("Invalid value for `last_open_height`, must not be `None`")  # noqa: E501

        self._last_open_height = last_open_height

    @property
    def last_repay_height(self):
        """Gets the last_repay_height of this Borrower.  # noqa: E501


        :return: The last_repay_height of this Borrower.  # noqa: E501
        :rtype: int
        """
        return self._last_repay_height

    @last_repay_height.setter
    def last_repay_height(self, last_repay_height):
        """Sets the last_repay_height of this Borrower.


        :param last_repay_height: The last_repay_height of this Borrower.  # noqa: E501
        :type: int
        """
        if last_repay_height is None:
            raise ValueError("Invalid value for `last_repay_height`, must not be `None`")  # noqa: E501

        self._last_repay_height = last_repay_height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Borrower, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Borrower):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpgradeVote(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'node_address': 'str',
        'vote': 'str'
    }

    attribute_map = {
        'node_address': 'node_address',
        'vote': 'vote'
    }

    def __init__(self, node_address=None, vote=None):  # noqa: E501
        """UpgradeVote - a model defined in Swagger"""  # noqa: E501
        self._node_address = None
        self._vote = None
        self.discriminator = None
        self.node_address = node_address
        self.vote = vote

    @property
    def node_address(self):
        """Gets the node_address of this UpgradeVote.  # noqa: E501

        the node address of the voter  # noqa: E501

        :return: The node_address of this UpgradeVote.  # noqa: E501
        :rtype: str
        """
        return self._node_address

    @node_address.setter
    def node_address(self, node_address):
        """Sets the node_address of this UpgradeVote.

        the node address of the voter  # noqa: E501

        :param node_address: The node_address of this UpgradeVote.  # noqa: E501
        :type: str
        """
        if node_address is None:
            raise ValueError("Invalid value for `node_address`, must not be `None`")  # noqa: E501

        self._node_address = node_address

    @property
    def vote(self):
        """Gets the vote of this UpgradeVote.  # noqa: E501

        the vote cast by the node  # noqa: E501

        :return: The vote of this UpgradeVote.  # noqa: E501
        :rtype: str
        """
        return self._vote

    @vote.setter
    def vote(self, vote):
        """Sets the vote of this UpgradeVote.

        the vote cast by the node  # noqa: E501

        :param vote: The vote of this UpgradeVote.  # noqa: E501
        :type: str
        """
        if vote is None:
            raise ValueError("Invalid value for `vote`, must not be `None`")  # noqa: E501
        allowed_values = ["approve", "reject"]  # noqa: E501
        if vote not in allowed_values:
            raise ValueError(
                "Invalid value for `vote` ({0}), must be one of {1}"  # noqa: E501
                .format(vote, allowed_values)
            )

        self._vote = vote

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpgradeVote, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpgradeVote):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Saver(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset': 'str',
        'asset_address': 'str',
        'last_add_height': 'int',
        'last_withdraw_height': 'int',
        'units': 'str',
        'asset_deposit_value': 'str',
        'asset_redeem_value': 'str',
        'growth_pct': 'str'
    }

    attribute_map = {
        'asset': 'asset',
        'asset_address': 'asset_address',
        'last_add_height': 'last_add_height',
        'last_withdraw_height': 'last_withdraw_height',
        'units': 'units',
        'asset_deposit_value': 'asset_deposit_value',
        'asset_redeem_value': 'asset_redeem_value',
        'growth_pct': 'growth_pct'
    }

    def __init__(self, asset=None, asset_address=None, last_add_height=None, last_withdraw_height=None, units=None, asset_deposit_value=None, asset_redeem_value=None, growth_pct=None):  # noqa: E501
        """Saver - a model defined in Swagger"""  # noqa: E501
        self._asset = None
        self._asset_address = None
        self._last_add_height = None
        self._last_withdraw_height = None
        self._units = None
        self._asset_deposit_value = None
        self._asset_redeem_value = None
        self._growth_pct = None
        self.discriminator = None
        self.asset = asset
        self.asset_address = asset_address
        if last_add_height is not None:
            self.last_add_height = last_add_height
        if last_withdraw_height is not None:
            self.last_withdraw_height = last_withdraw_height
        self.units = units
        self.asset_deposit_value = asset_deposit_value
        self.asset_redeem_value = asset_redeem_value
        self.growth_pct = growth_pct

    @property
    def asset(self):
        """Gets the asset of this Saver.  # noqa: E501


        :return: The asset of this Saver.  # noqa: E501
        :rtype: str
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """Sets the asset of this Saver.


        :param asset: The asset of this Saver.  # noqa: E501
        :type: str
        """
        if asset is None:
            raise ValueError("Invalid value for `asset`, must not be `None`")  # noqa: E501

        self._asset = asset

    @property
    def asset_address(self):
        """Gets the asset_address of this Saver.  # noqa: E501


        :return: The asset_address of this Saver.  # noqa: E501
        :rtype: str
        """
        return self._asset_address

    @asset_address.setter
    def asset_address(self, asset_address):
        """Sets the asset_address of this Saver.


        :param asset_address: The asset_address of this Saver.  # noqa: E501
        :type: str
        """
        if asset_address is None:
            raise ValueError("Invalid value for `asset_address`, must not be `None`")  # noqa: E501

        self._asset_address = asset_address

    @property
    def last_add_height(self):
        """Gets the last_add_height of this Saver.  # noqa: E501


        :return: The last_add_height of this Saver.  # noqa: E501
        :rtype: int
        """
        return self._last_add_height

    @last_add_height.setter
    def last_add_height(self, last_add_height):
        """Sets the last_add_height of this Saver.


        :param last_add_height: The last_add_height of this Saver.  # noqa: E501
        :type: int
        """

        self._last_add_height = last_add_height

    @property
    def last_withdraw_height(self):
        """Gets the last_withdraw_height of this Saver.  # noqa: E501


        :return: The last_withdraw_height of this Saver.  # noqa: E501
        :rtype: int
        """
        return self._last_withdraw_height

    @last_withdraw_height.setter
    def last_withdraw_height(self, last_withdraw_height):
        """Sets the last_withdraw_height of this Saver.


        :param last_withdraw_height: The last_withdraw_height of this Saver.  # noqa: E501
        :type: int
        """

        self._last_withdraw_height = last_withdraw_height

    @property
    def units(self):
        """Gets the units of this Saver.  # noqa: E501


        :return: The units of this Saver.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this Saver.


        :param units: The units of this Saver.  # noqa: E501
        :type: str
        """
        if units is None:
            raise ValueError("Invalid value for `units`, must not be `None`")  # noqa: E501

        self._units = units

    @property
    def asset_deposit_value(self):
        """Gets the asset_deposit_value of this Saver.  # noqa: E501


        :return: The asset_deposit_value of this Saver.  # noqa: E501
        :rtype: str
        """
        return self._asset_deposit_value

    @asset_deposit_value.setter
    def asset_deposit_value(self, asset_deposit_value):
        """Sets the asset_deposit_value of this Saver.


        :param asset_deposit_value: The asset_deposit_value of this Saver.  # noqa: E501
        :type: str
        """
        if asset_deposit_value is None:
            raise ValueError("Invalid value for `asset_deposit_value`, must not be `None`")  # noqa: E501

        self._asset_deposit_value = asset_deposit_value

    @property
    def asset_redeem_value(self):
        """Gets the asset_redeem_value of this Saver.  # noqa: E501


        :return: The asset_redeem_value of this Saver.  # noqa: E501
        :rtype: str
        """
        return self._asset_redeem_value

    @asset_redeem_value.setter
    def asset_redeem_value(self, asset_redeem_value):
        """Sets the asset_redeem_value of this Saver.


        :param asset_redeem_value: The asset_redeem_value of this Saver.  # noqa: E501
        :type: str
        """
        if asset_redeem_value is None:
            raise ValueError("Invalid value for `asset_redeem_value`, must not be `None`")  # noqa: E501

        self._asset_redeem_value = asset_redeem_value

    @property
    def growth_pct(self):
        """Gets the growth_pct of this Saver.  # noqa: E501


        :return: The growth_pct of this Saver.  # noqa: E501
        :rtype: str
        """
        return self._growth_pct

    @growth_pct.setter
    def growth_pct(self, growth_pct):
        """Sets the growth_pct of this Saver.


        :param growth_pct: The growth_pct of this Saver.  # noqa: E501
        :type: str
        """
        if growth_pct is None:
            raise ValueError("Invalid value for `growth_pct`, must not be `None`")  # noqa: E501

        self._growth_pct = growth_pct

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Saver, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Saver):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ConstantsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'int_64_values': 'dict(str, str)',
        'bool_values': 'dict(str, str)',
        'string_values': 'dict(str, str)'
    }

    attribute_map = {
        'int_64_values': 'int_64_values',
        'bool_values': 'bool_values',
        'string_values': 'string_values'
    }

    def __init__(self, int_64_values=None, bool_values=None, string_values=None):  # noqa: E501
        """ConstantsResponse - a model defined in Swagger"""  # noqa: E501
        self._int_64_values = None
        self._bool_values = None
        self._string_values = None
        self.discriminator = None
        if int_64_values is not None:
            self.int_64_values = int_64_values
        if bool_values is not None:
            self.bool_values = bool_values
        if string_values is not None:
            self.string_values = string_values

    @property
    def int_64_values(self):
        """Gets the int_64_values of this ConstantsResponse.  # noqa: E501


        :return: The int_64_values of this ConstantsResponse.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._int_64_values

    @int_64_values.setter
    def int_64_values(self, int_64_values):
        """Sets the int_64_values of this ConstantsResponse.


        :param int_64_values: The int_64_values of this ConstantsResponse.  # noqa: E501
        :type: dict(str, str)
        """

        self._int_64_values = int_64_values

    @property
    def bool_values(self):
        """Gets the bool_values of this ConstantsResponse.  # noqa: E501


        :return: The bool_values of this ConstantsResponse.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._bool_values

    @bool_values.setter
    def bool_values(self, bool_values):
        """Sets the bool_values of this ConstantsResponse.


        :param bool_values: The bool_values of this ConstantsResponse.  # noqa: E501
        :type: dict(str, str)
        """

        self._bool_values = bool_values

    @property
    def string_values(self):
        """Gets the string_values of this ConstantsResponse.  # noqa: E501


        :return: The string_values of this ConstantsResponse.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._string_values

    @string_values.setter
    def string_values(self, string_values):
        """Sets the string_values of this ConstantsResponse.


        :param string_values: The string_values of this ConstantsResponse.  # noqa: E501
        :type: dict(str, str)
        """

        self._string_values = string_values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConstantsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConstantsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import xchainpy2_thornode
from xchainpy2_thornode.api.streaming_swap_api import StreamingSwapApi  # noqa: E501
from xchainpy2_thornode.rest import ApiException


class TestStreamingSwapApi(unittest.TestCase):
    """StreamingSwapApi unit test stubs"""

    def setUp(self):
        self.api = StreamingSwapApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_stream_swap(self):
        """Test case for stream_swap

        """
        pass

    def test_stream_swaps(self):
        """Test case for stream_swaps

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class QuoteSaverWithdrawResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'inbound_address': 'str',
        'inbound_confirmation_blocks': 'int',
        'inbound_confirmation_seconds': 'int',
        'outbound_delay_blocks': 'int',
        'outbound_delay_seconds': 'int',
        'fees': 'QuoteFees',
        'router': 'str',
        'expiry': 'int',
        'warning': 'str',
        'notes': 'str',
        'dust_threshold': 'str',
        'recommended_min_amount_in': 'str',
        'recommended_gas_rate': 'str',
        'gas_rate_units': 'str',
        'memo': 'str',
        'dust_amount': 'str',
        'expected_amount_out': 'str'
    }

    attribute_map = {
        'inbound_address': 'inbound_address',
        'inbound_confirmation_blocks': 'inbound_confirmation_blocks',
        'inbound_confirmation_seconds': 'inbound_confirmation_seconds',
        'outbound_delay_blocks': 'outbound_delay_blocks',
        'outbound_delay_seconds': 'outbound_delay_seconds',
        'fees': 'fees',
        'router': 'router',
        'expiry': 'expiry',
        'warning': 'warning',
        'notes': 'notes',
        'dust_threshold': 'dust_threshold',
        'recommended_min_amount_in': 'recommended_min_amount_in',
        'recommended_gas_rate': 'recommended_gas_rate',
        'gas_rate_units': 'gas_rate_units',
        'memo': 'memo',
        'dust_amount': 'dust_amount',
        'expected_amount_out': 'expected_amount_out'
    }

    def __init__(self, inbound_address=None, inbound_confirmation_blocks=None, inbound_confirmation_seconds=None, outbound_delay_blocks=None, outbound_delay_seconds=None, fees=None, router=None, expiry=None, warning=None, notes=None, dust_threshold=None, recommended_min_amount_in=None, recommended_gas_rate=None, gas_rate_units=None, memo=None, dust_amount=None, expected_amount_out=None):  # noqa: E501
        """QuoteSaverWithdrawResponse - a model defined in Swagger"""  # noqa: E501
        self._inbound_address = None
        self._inbound_confirmation_blocks = None
        self._inbound_confirmation_seconds = None
        self._outbound_delay_blocks = None
        self._outbound_delay_seconds = None
        self._fees = None
        self._router = None
        self._expiry = None
        self._warning = None
        self._notes = None
        self._dust_threshold = None
        self._recommended_min_amount_in = None
        self._recommended_gas_rate = None
        self._gas_rate_units = None
        self._memo = None
        self._dust_amount = None
        self._expected_amount_out = None
        self.discriminator = None
        self.inbound_address = inbound_address
        if inbound_confirmation_blocks is not None:
            self.inbound_confirmation_blocks = inbound_confirmation_blocks
        if inbound_confirmation_seconds is not None:
            self.inbound_confirmation_seconds = inbound_confirmation_seconds
        self.outbound_delay_blocks = outbound_delay_blocks
        self.outbound_delay_seconds = outbound_delay_seconds
        self.fees = fees
        if router is not None:
            self.router = router
        self.expiry = expiry
        self.warning = warning
        self.notes = notes
        if dust_threshold is not None:
            self.dust_threshold = dust_threshold
        if recommended_min_amount_in is not None:
            self.recommended_min_amount_in = recommended_min_amount_in
        self.recommended_gas_rate = recommended_gas_rate
        self.gas_rate_units = gas_rate_units
        self.memo = memo
        self.dust_amount = dust_amount
        self.expected_amount_out = expected_amount_out

    @property
    def inbound_address(self):
        """Gets the inbound_address of this QuoteSaverWithdrawResponse.  # noqa: E501

        the inbound address for the transaction on the source chain  # noqa: E501

        :return: The inbound_address of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: str
        """
        return self._inbound_address

    @inbound_address.setter
    def inbound_address(self, inbound_address):
        """Sets the inbound_address of this QuoteSaverWithdrawResponse.

        the inbound address for the transaction on the source chain  # noqa: E501

        :param inbound_address: The inbound_address of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: str
        """
        if inbound_address is None:
            raise ValueError("Invalid value for `inbound_address`, must not be `None`")  # noqa: E501

        self._inbound_address = inbound_address

    @property
    def inbound_confirmation_blocks(self):
        """Gets the inbound_confirmation_blocks of this QuoteSaverWithdrawResponse.  # noqa: E501

        the approximate number of source chain blocks required before processing  # noqa: E501

        :return: The inbound_confirmation_blocks of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: int
        """
        return self._inbound_confirmation_blocks

    @inbound_confirmation_blocks.setter
    def inbound_confirmation_blocks(self, inbound_confirmation_blocks):
        """Sets the inbound_confirmation_blocks of this QuoteSaverWithdrawResponse.

        the approximate number of source chain blocks required before processing  # noqa: E501

        :param inbound_confirmation_blocks: The inbound_confirmation_blocks of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: int
        """

        self._inbound_confirmation_blocks = inbound_confirmation_blocks

    @property
    def inbound_confirmation_seconds(self):
        """Gets the inbound_confirmation_seconds of this QuoteSaverWithdrawResponse.  # noqa: E501

        the approximate seconds for block confirmations required before processing  # noqa: E501

        :return: The inbound_confirmation_seconds of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: int
        """
        return self._inbound_confirmation_seconds

    @inbound_confirmation_seconds.setter
    def inbound_confirmation_seconds(self, inbound_confirmation_seconds):
        """Sets the inbound_confirmation_seconds of this QuoteSaverWithdrawResponse.

        the approximate seconds for block confirmations required before processing  # noqa: E501

        :param inbound_confirmation_seconds: The inbound_confirmation_seconds of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: int
        """

        self._inbound_confirmation_seconds = inbound_confirmation_seconds

    @property
    def outbound_delay_blocks(self):
        """Gets the outbound_delay_blocks of this QuoteSaverWithdrawResponse.  # noqa: E501

        the number of thorchain blocks the outbound will be delayed  # noqa: E501

        :return: The outbound_delay_blocks of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: int
        """
        return self._outbound_delay_blocks

    @outbound_delay_blocks.setter
    def outbound_delay_blocks(self, outbound_delay_blocks):
        """Sets the outbound_delay_blocks of this QuoteSaverWithdrawResponse.

        the number of thorchain blocks the outbound will be delayed  # noqa: E501

        :param outbound_delay_blocks: The outbound_delay_blocks of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: int
        """
        if outbound_delay_blocks is None:
            raise ValueError("Invalid value for `outbound_delay_blocks`, must not be `None`")  # noqa: E501

        self._outbound_delay_blocks = outbound_delay_blocks

    @property
    def outbound_delay_seconds(self):
        """Gets the outbound_delay_seconds of this QuoteSaverWithdrawResponse.  # noqa: E501

        the approximate seconds for the outbound delay before it will be sent  # noqa: E501

        :return: The outbound_delay_seconds of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: int
        """
        return self._outbound_delay_seconds

    @outbound_delay_seconds.setter
    def outbound_delay_seconds(self, outbound_delay_seconds):
        """Sets the outbound_delay_seconds of this QuoteSaverWithdrawResponse.

        the approximate seconds for the outbound delay before it will be sent  # noqa: E501

        :param outbound_delay_seconds: The outbound_delay_seconds of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: int
        """
        if outbound_delay_seconds is None:
            raise ValueError("Invalid value for `outbound_delay_seconds`, must not be `None`")  # noqa: E501

        self._outbound_delay_seconds = outbound_delay_seconds

    @property
    def fees(self):
        """Gets the fees of this QuoteSaverWithdrawResponse.  # noqa: E501


        :return: The fees of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: QuoteFees
        """
        return self._fees

    @fees.setter
    def fees(self, fees):
        """Sets the fees of this QuoteSaverWithdrawResponse.


        :param fees: The fees of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: QuoteFees
        """
        if fees is None:
            raise ValueError("Invalid value for `fees`, must not be `None`")  # noqa: E501

        self._fees = fees

    @property
    def router(self):
        """Gets the router of this QuoteSaverWithdrawResponse.  # noqa: E501

        the EVM chain router contract address  # noqa: E501

        :return: The router of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: str
        """
        return self._router

    @router.setter
    def router(self, router):
        """Sets the router of this QuoteSaverWithdrawResponse.

        the EVM chain router contract address  # noqa: E501

        :param router: The router of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: str
        """

        self._router = router

    @property
    def expiry(self):
        """Gets the expiry of this QuoteSaverWithdrawResponse.  # noqa: E501

        expiration timestamp in unix seconds  # noqa: E501

        :return: The expiry of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: int
        """
        return self._expiry

    @expiry.setter
    def expiry(self, expiry):
        """Sets the expiry of this QuoteSaverWithdrawResponse.

        expiration timestamp in unix seconds  # noqa: E501

        :param expiry: The expiry of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: int
        """
        if expiry is None:
            raise ValueError("Invalid value for `expiry`, must not be `None`")  # noqa: E501

        self._expiry = expiry

    @property
    def warning(self):
        """Gets the warning of this QuoteSaverWithdrawResponse.  # noqa: E501

        static warning message  # noqa: E501

        :return: The warning of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: str
        """
        return self._warning

    @warning.setter
    def warning(self, warning):
        """Sets the warning of this QuoteSaverWithdrawResponse.

        static warning message  # noqa: E501

        :param warning: The warning of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: str
        """
        if warning is None:
            raise ValueError("Invalid value for `warning`, must not be `None`")  # noqa: E501

        self._warning = warning

    @property
    def notes(self):
        """Gets the notes of this QuoteSaverWithdrawResponse.  # noqa: E501

        chain specific quote notes  # noqa: E501

        :return: The notes of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this QuoteSaverWithdrawResponse.

        chain specific quote notes  # noqa: E501

        :param notes: The notes of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: str
        """
        if notes is None:
            raise ValueError("Invalid value for `notes`, must not be `None`")  # noqa: E501

        self._notes = notes

    @property
    def dust_threshold(self):
        """Gets the dust_threshold of this QuoteSaverWithdrawResponse.  # noqa: E501

        Defines the minimum transaction size for the chain in base units (sats, wei, uatom). Transactions with asset amounts lower than the dust_threshold are ignored.  # noqa: E501

        :return: The dust_threshold of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: str
        """
        return self._dust_threshold

    @dust_threshold.setter
    def dust_threshold(self, dust_threshold):
        """Sets the dust_threshold of this QuoteSaverWithdrawResponse.

        Defines the minimum transaction size for the chain in base units (sats, wei, uatom). Transactions with asset amounts lower than the dust_threshold are ignored.  # noqa: E501

        :param dust_threshold: The dust_threshold of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: str
        """

        self._dust_threshold = dust_threshold

    @property
    def recommended_min_amount_in(self):
        """Gets the recommended_min_amount_in of this QuoteSaverWithdrawResponse.  # noqa: E501

        The recommended minimum inbound amount for this transaction type & inbound asset. Sending less than this amount could result in failed refunds.  # noqa: E501

        :return: The recommended_min_amount_in of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: str
        """
        return self._recommended_min_amount_in

    @recommended_min_amount_in.setter
    def recommended_min_amount_in(self, recommended_min_amount_in):
        """Sets the recommended_min_amount_in of this QuoteSaverWithdrawResponse.

        The recommended minimum inbound amount for this transaction type & inbound asset. Sending less than this amount could result in failed refunds.  # noqa: E501

        :param recommended_min_amount_in: The recommended_min_amount_in of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: str
        """

        self._recommended_min_amount_in = recommended_min_amount_in

    @property
    def recommended_gas_rate(self):
        """Gets the recommended_gas_rate of this QuoteSaverWithdrawResponse.  # noqa: E501

        the recommended gas rate to use for the inbound to ensure timely confirmation  # noqa: E501

        :return: The recommended_gas_rate of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: str
        """
        return self._recommended_gas_rate

    @recommended_gas_rate.setter
    def recommended_gas_rate(self, recommended_gas_rate):
        """Sets the recommended_gas_rate of this QuoteSaverWithdrawResponse.

        the recommended gas rate to use for the inbound to ensure timely confirmation  # noqa: E501

        :param recommended_gas_rate: The recommended_gas_rate of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: str
        """
        if recommended_gas_rate is None:
            raise ValueError("Invalid value for `recommended_gas_rate`, must not be `None`")  # noqa: E501

        self._recommended_gas_rate = recommended_gas_rate

    @property
    def gas_rate_units(self):
        """Gets the gas_rate_units of this QuoteSaverWithdrawResponse.  # noqa: E501

        the units of the recommended gas rate  # noqa: E501

        :return: The gas_rate_units of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: str
        """
        return self._gas_rate_units

    @gas_rate_units.setter
    def gas_rate_units(self, gas_rate_units):
        """Sets the gas_rate_units of this QuoteSaverWithdrawResponse.

        the units of the recommended gas rate  # noqa: E501

        :param gas_rate_units: The gas_rate_units of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: str
        """
        if gas_rate_units is None:
            raise ValueError("Invalid value for `gas_rate_units`, must not be `None`")  # noqa: E501

        self._gas_rate_units = gas_rate_units

    @property
    def memo(self):
        """Gets the memo of this QuoteSaverWithdrawResponse.  # noqa: E501

        generated memo for the withdraw, the client can use this OR send the dust amount  # noqa: E501

        :return: The memo of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: str
        """
        return self._memo

    @memo.setter
    def memo(self, memo):
        """Sets the memo of this QuoteSaverWithdrawResponse.

        generated memo for the withdraw, the client can use this OR send the dust amount  # noqa: E501

        :param memo: The memo of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: str
        """
        if memo is None:
            raise ValueError("Invalid value for `memo`, must not be `None`")  # noqa: E501

        self._memo = memo

    @property
    def dust_amount(self):
        """Gets the dust_amount of this QuoteSaverWithdrawResponse.  # noqa: E501

        the dust amount of the target asset the user should send to initialize the withdraw, the client can send this OR provide the memo  # noqa: E501

        :return: The dust_amount of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: str
        """
        return self._dust_amount

    @dust_amount.setter
    def dust_amount(self, dust_amount):
        """Sets the dust_amount of this QuoteSaverWithdrawResponse.

        the dust amount of the target asset the user should send to initialize the withdraw, the client can send this OR provide the memo  # noqa: E501

        :param dust_amount: The dust_amount of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: str
        """
        if dust_amount is None:
            raise ValueError("Invalid value for `dust_amount`, must not be `None`")  # noqa: E501

        self._dust_amount = dust_amount

    @property
    def expected_amount_out(self):
        """Gets the expected_amount_out of this QuoteSaverWithdrawResponse.  # noqa: E501

        the amount of the target asset the user can expect to withdraw after fees in 1e8 decimals  # noqa: E501

        :return: The expected_amount_out of this QuoteSaverWithdrawResponse.  # noqa: E501
        :rtype: str
        """
        return self._expected_amount_out

    @expected_amount_out.setter
    def expected_amount_out(self, expected_amount_out):
        """Sets the expected_amount_out of this QuoteSaverWithdrawResponse.

        the amount of the target asset the user can expect to withdraw after fees in 1e8 decimals  # noqa: E501

        :param expected_amount_out: The expected_amount_out of this QuoteSaverWithdrawResponse.  # noqa: E501
        :type: str
        """
        if expected_amount_out is None:
            raise ValueError("Invalid value for `expected_amount_out`, must not be `None`")  # noqa: E501

        self._expected_amount_out = expected_amount_out

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(QuoteSaverWithdrawResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QuoteSaverWithdrawResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import xchainpy2_thornode
from xchainpy2_thornode.models.keysign_info import KeysignInfo  # noqa: E501
from xchainpy2_thornode.rest import ApiException


class TestKeysignInfo(unittest.TestCase):
    """KeysignInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testKeysignInfo(self):
        """Test KeysignInfo"""
        # FIXME: construct object with mandatory attributes with example values
        # model = xchainpy2_thornode.models.keysign_info.KeysignInfo()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpgradeProposal(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'height': 'int',
        'info': 'str',
        'approved': 'bool',
        'approved_percent': 'str',
        'validators_to_quorum': 'int'
    }

    attribute_map = {
        'name': 'name',
        'height': 'height',
        'info': 'info',
        'approved': 'approved',
        'approved_percent': 'approved_percent',
        'validators_to_quorum': 'validators_to_quorum'
    }

    def __init__(self, name=None, height=None, info=None, approved=None, approved_percent=None, validators_to_quorum=None):  # noqa: E501
        """UpgradeProposal - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._height = None
        self._info = None
        self._approved = None
        self._approved_percent = None
        self._validators_to_quorum = None
        self.discriminator = None
        self.name = name
        self.height = height
        self.info = info
        if approved is not None:
            self.approved = approved
        if approved_percent is not None:
            self.approved_percent = approved_percent
        if validators_to_quorum is not None:
            self.validators_to_quorum = validators_to_quorum

    @property
    def name(self):
        """Gets the name of this UpgradeProposal.  # noqa: E501

        the name of the upgrade  # noqa: E501

        :return: The name of this UpgradeProposal.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpgradeProposal.

        the name of the upgrade  # noqa: E501

        :param name: The name of this UpgradeProposal.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def height(self):
        """Gets the height of this UpgradeProposal.  # noqa: E501

        the block height at which the upgrade will occur  # noqa: E501

        :return: The height of this UpgradeProposal.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this UpgradeProposal.

        the block height at which the upgrade will occur  # noqa: E501

        :param height: The height of this UpgradeProposal.  # noqa: E501
        :type: int
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501

        self._height = height

    @property
    def info(self):
        """Gets the info of this UpgradeProposal.  # noqa: E501

        the description of the upgrade, typically json with URLs to binaries for use with automation tools  # noqa: E501

        :return: The info of this UpgradeProposal.  # noqa: E501
        :rtype: str
        """
        return self._info

    @info.setter
    def info(self, info):
        """Sets the info of this UpgradeProposal.

        the description of the upgrade, typically json with URLs to binaries for use with automation tools  # noqa: E501

        :param info: The info of this UpgradeProposal.  # noqa: E501
        :type: str
        """
        if info is None:
            raise ValueError("Invalid value for `info`, must not be `None`")  # noqa: E501

        self._info = info

    @property
    def approved(self):
        """Gets the approved of this UpgradeProposal.  # noqa: E501

        whether the upgrade has been approved by the active validators  # noqa: E501

        :return: The approved of this UpgradeProposal.  # noqa: E501
        :rtype: bool
        """
        return self._approved

    @approved.setter
    def approved(self, approved):
        """Sets the approved of this UpgradeProposal.

        whether the upgrade has been approved by the active validators  # noqa: E501

        :param approved: The approved of this UpgradeProposal.  # noqa: E501
        :type: bool
        """

        self._approved = approved

    @property
    def approved_percent(self):
        """Gets the approved_percent of this UpgradeProposal.  # noqa: E501

        the percentage of active validators that have approved the upgrade  # noqa: E501

        :return: The approved_percent of this UpgradeProposal.  # noqa: E501
        :rtype: str
        """
        return self._approved_percent

    @approved_percent.setter
    def approved_percent(self, approved_percent):
        """Sets the approved_percent of this UpgradeProposal.

        the percentage of active validators that have approved the upgrade  # noqa: E501

        :param approved_percent: The approved_percent of this UpgradeProposal.  # noqa: E501
        :type: str
        """

        self._approved_percent = approved_percent

    @property
    def validators_to_quorum(self):
        """Gets the validators_to_quorum of this UpgradeProposal.  # noqa: E501

        the amount of additional active validators required to reach quorum for the upgrade  # noqa: E501

        :return: The validators_to_quorum of this UpgradeProposal.  # noqa: E501
        :rtype: int
        """
        return self._validators_to_quorum

    @validators_to_quorum.setter
    def validators_to_quorum(self, validators_to_quorum):
        """Sets the validators_to_quorum of this UpgradeProposal.

        the amount of additional active validators required to reach quorum for the upgrade  # noqa: E501

        :param validators_to_quorum: The validators_to_quorum of this UpgradeProposal.  # noqa: E501
        :type: int
        """

        self._validators_to_quorum = validators_to_quorum

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpgradeProposal, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpgradeProposal):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InboundObservedStage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'started': 'bool',
        'pre_confirmation_count': 'int',
        'final_count': 'int',
        'completed': 'bool'
    }

    attribute_map = {
        'started': 'started',
        'pre_confirmation_count': 'pre_confirmation_count',
        'final_count': 'final_count',
        'completed': 'completed'
    }

    def __init__(self, started=None, pre_confirmation_count=None, final_count=None, completed=None):  # noqa: E501
        """InboundObservedStage - a model defined in Swagger"""  # noqa: E501
        self._started = None
        self._pre_confirmation_count = None
        self._final_count = None
        self._completed = None
        self.discriminator = None
        if started is not None:
            self.started = started
        if pre_confirmation_count is not None:
            self.pre_confirmation_count = pre_confirmation_count
        self.final_count = final_count
        self.completed = completed

    @property
    def started(self):
        """Gets the started of this InboundObservedStage.  # noqa: E501

        returns true if any nodes have observed the transaction (to be deprecated in favour of counts)  # noqa: E501

        :return: The started of this InboundObservedStage.  # noqa: E501
        :rtype: bool
        """
        return self._started

    @started.setter
    def started(self, started):
        """Sets the started of this InboundObservedStage.

        returns true if any nodes have observed the transaction (to be deprecated in favour of counts)  # noqa: E501

        :param started: The started of this InboundObservedStage.  # noqa: E501
        :type: bool
        """

        self._started = started

    @property
    def pre_confirmation_count(self):
        """Gets the pre_confirmation_count of this InboundObservedStage.  # noqa: E501

        number of signers for pre-confirmation-counting observations  # noqa: E501

        :return: The pre_confirmation_count of this InboundObservedStage.  # noqa: E501
        :rtype: int
        """
        return self._pre_confirmation_count

    @pre_confirmation_count.setter
    def pre_confirmation_count(self, pre_confirmation_count):
        """Sets the pre_confirmation_count of this InboundObservedStage.

        number of signers for pre-confirmation-counting observations  # noqa: E501

        :param pre_confirmation_count: The pre_confirmation_count of this InboundObservedStage.  # noqa: E501
        :type: int
        """

        self._pre_confirmation_count = pre_confirmation_count

    @property
    def final_count(self):
        """Gets the final_count of this InboundObservedStage.  # noqa: E501

        number of signers for final observations, after any confirmation counting complete  # noqa: E501

        :return: The final_count of this InboundObservedStage.  # noqa: E501
        :rtype: int
        """
        return self._final_count

    @final_count.setter
    def final_count(self, final_count):
        """Sets the final_count of this InboundObservedStage.

        number of signers for final observations, after any confirmation counting complete  # noqa: E501

        :param final_count: The final_count of this InboundObservedStage.  # noqa: E501
        :type: int
        """
        if final_count is None:
            raise ValueError("Invalid value for `final_count`, must not be `None`")  # noqa: E501

        self._final_count = final_count

    @property
    def completed(self):
        """Gets the completed of this InboundObservedStage.  # noqa: E501

        returns true if no transaction observation remains to be done  # noqa: E501

        :return: The completed of this InboundObservedStage.  # noqa: E501
        :rtype: bool
        """
        return self._completed

    @completed.setter
    def completed(self, completed):
        """Sets the completed of this InboundObservedStage.

        returns true if no transaction observation remains to be done  # noqa: E501

        :param completed: The completed of this InboundObservedStage.  # noqa: E501
        :type: bool
        """
        if completed is None:
            raise ValueError("Invalid value for `completed`, must not be `None`")  # noqa: E501

        self._completed = completed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InboundObservedStage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InboundObservedStage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SwapperCloutResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address': 'str',
        'score': 'str',
        'reclaimed': 'str',
        'spent': 'str',
        'last_spent_height': 'int',
        'last_reclaim_height': 'int'
    }

    attribute_map = {
        'address': 'address',
        'score': 'score',
        'reclaimed': 'reclaimed',
        'spent': 'spent',
        'last_spent_height': 'last_spent_height',
        'last_reclaim_height': 'last_reclaim_height'
    }

    def __init__(self, address=None, score=None, reclaimed=None, spent=None, last_spent_height=None, last_reclaim_height=None):  # noqa: E501
        """SwapperCloutResponse - a model defined in Swagger"""  # noqa: E501
        self._address = None
        self._score = None
        self._reclaimed = None
        self._spent = None
        self._last_spent_height = None
        self._last_reclaim_height = None
        self.discriminator = None
        self.address = address
        if score is not None:
            self.score = score
        if reclaimed is not None:
            self.reclaimed = reclaimed
        if spent is not None:
            self.spent = spent
        if last_spent_height is not None:
            self.last_spent_height = last_spent_height
        if last_reclaim_height is not None:
            self.last_reclaim_height = last_reclaim_height

    @property
    def address(self):
        """Gets the address of this SwapperCloutResponse.  # noqa: E501

        address associated with this clout account  # noqa: E501

        :return: The address of this SwapperCloutResponse.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this SwapperCloutResponse.

        address associated with this clout account  # noqa: E501

        :param address: The address of this SwapperCloutResponse.  # noqa: E501
        :type: str
        """
        if address is None:
            raise ValueError("Invalid value for `address`, must not be `None`")  # noqa: E501

        self._address = address

    @property
    def score(self):
        """Gets the score of this SwapperCloutResponse.  # noqa: E501

        clout score, which is the amount of rune spent on swap fees  # noqa: E501

        :return: The score of this SwapperCloutResponse.  # noqa: E501
        :rtype: str
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this SwapperCloutResponse.

        clout score, which is the amount of rune spent on swap fees  # noqa: E501

        :param score: The score of this SwapperCloutResponse.  # noqa: E501
        :type: str
        """

        self._score = score

    @property
    def reclaimed(self):
        """Gets the reclaimed of this SwapperCloutResponse.  # noqa: E501

        amount of clout that has been reclaimed in total over time (observed clout spent)  # noqa: E501

        :return: The reclaimed of this SwapperCloutResponse.  # noqa: E501
        :rtype: str
        """
        return self._reclaimed

    @reclaimed.setter
    def reclaimed(self, reclaimed):
        """Sets the reclaimed of this SwapperCloutResponse.

        amount of clout that has been reclaimed in total over time (observed clout spent)  # noqa: E501

        :param reclaimed: The reclaimed of this SwapperCloutResponse.  # noqa: E501
        :type: str
        """

        self._reclaimed = reclaimed

    @property
    def spent(self):
        """Gets the spent of this SwapperCloutResponse.  # noqa: E501

        amount of clout that has been spent in total over time  # noqa: E501

        :return: The spent of this SwapperCloutResponse.  # noqa: E501
        :rtype: str
        """
        return self._spent

    @spent.setter
    def spent(self, spent):
        """Sets the spent of this SwapperCloutResponse.

        amount of clout that has been spent in total over time  # noqa: E501

        :param spent: The spent of this SwapperCloutResponse.  # noqa: E501
        :type: str
        """

        self._spent = spent

    @property
    def last_spent_height(self):
        """Gets the last_spent_height of this SwapperCloutResponse.  # noqa: E501

        last block height that clout was spent  # noqa: E501

        :return: The last_spent_height of this SwapperCloutResponse.  # noqa: E501
        :rtype: int
        """
        return self._last_spent_height

    @last_spent_height.setter
    def last_spent_height(self, last_spent_height):
        """Sets the last_spent_height of this SwapperCloutResponse.

        last block height that clout was spent  # noqa: E501

        :param last_spent_height: The last_spent_height of this SwapperCloutResponse.  # noqa: E501
        :type: int
        """

        self._last_spent_height = last_spent_height

    @property
    def last_reclaim_height(self):
        """Gets the last_reclaim_height of this SwapperCloutResponse.  # noqa: E501

        last block height that clout was reclaimed  # noqa: E501

        :return: The last_reclaim_height of this SwapperCloutResponse.  # noqa: E501
        :rtype: int
        """
        return self._last_reclaim_height

    @last_reclaim_height.setter
    def last_reclaim_height(self, last_reclaim_height):
        """Sets the last_reclaim_height of this SwapperCloutResponse.

        last block height that clout was reclaimed  # noqa: E501

        :param last_reclaim_height: The last_reclaim_height of this SwapperCloutResponse.  # noqa: E501
        :type: int
        """

        self._last_reclaim_height = last_reclaim_height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SwapperCloutResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SwapperCloutResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StreamingSwap(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tx_id': 'str',
        'interval': 'int',
        'quantity': 'int',
        'count': 'int',
        'last_height': 'int',
        'trade_target': 'str',
        'source_asset': 'str',
        'target_asset': 'str',
        'destination': 'str',
        'deposit': 'str',
        '_in': 'str',
        'out': 'str',
        'failed_swaps': 'list[int]',
        'failed_swap_reasons': 'list[str]'
    }

    attribute_map = {
        'tx_id': 'tx_id',
        'interval': 'interval',
        'quantity': 'quantity',
        'count': 'count',
        'last_height': 'last_height',
        'trade_target': 'trade_target',
        'source_asset': 'source_asset',
        'target_asset': 'target_asset',
        'destination': 'destination',
        'deposit': 'deposit',
        '_in': 'in',
        'out': 'out',
        'failed_swaps': 'failed_swaps',
        'failed_swap_reasons': 'failed_swap_reasons'
    }

    def __init__(self, tx_id=None, interval=None, quantity=None, count=None, last_height=None, trade_target=None, source_asset=None, target_asset=None, destination=None, deposit=None, _in=None, out=None, failed_swaps=None, failed_swap_reasons=None):  # noqa: E501
        """StreamingSwap - a model defined in Swagger"""  # noqa: E501
        self._tx_id = None
        self._interval = None
        self._quantity = None
        self._count = None
        self._last_height = None
        self._trade_target = None
        self._source_asset = None
        self._target_asset = None
        self._destination = None
        self._deposit = None
        self.__in = None
        self._out = None
        self._failed_swaps = None
        self._failed_swap_reasons = None
        self.discriminator = None
        if tx_id is not None:
            self.tx_id = tx_id
        if interval is not None:
            self.interval = interval
        if quantity is not None:
            self.quantity = quantity
        if count is not None:
            self.count = count
        if last_height is not None:
            self.last_height = last_height
        self.trade_target = trade_target
        if source_asset is not None:
            self.source_asset = source_asset
        if target_asset is not None:
            self.target_asset = target_asset
        if destination is not None:
            self.destination = destination
        self.deposit = deposit
        self._in = _in
        self.out = out
        if failed_swaps is not None:
            self.failed_swaps = failed_swaps
        if failed_swap_reasons is not None:
            self.failed_swap_reasons = failed_swap_reasons

    @property
    def tx_id(self):
        """Gets the tx_id of this StreamingSwap.  # noqa: E501

        the hash of a transaction  # noqa: E501

        :return: The tx_id of this StreamingSwap.  # noqa: E501
        :rtype: str
        """
        return self._tx_id

    @tx_id.setter
    def tx_id(self, tx_id):
        """Sets the tx_id of this StreamingSwap.

        the hash of a transaction  # noqa: E501

        :param tx_id: The tx_id of this StreamingSwap.  # noqa: E501
        :type: str
        """

        self._tx_id = tx_id

    @property
    def interval(self):
        """Gets the interval of this StreamingSwap.  # noqa: E501

        how often each swap is made, in blocks  # noqa: E501

        :return: The interval of this StreamingSwap.  # noqa: E501
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this StreamingSwap.

        how often each swap is made, in blocks  # noqa: E501

        :param interval: The interval of this StreamingSwap.  # noqa: E501
        :type: int
        """

        self._interval = interval

    @property
    def quantity(self):
        """Gets the quantity of this StreamingSwap.  # noqa: E501

        the total number of swaps in a streaming swaps  # noqa: E501

        :return: The quantity of this StreamingSwap.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this StreamingSwap.

        the total number of swaps in a streaming swaps  # noqa: E501

        :param quantity: The quantity of this StreamingSwap.  # noqa: E501
        :type: int
        """

        self._quantity = quantity

    @property
    def count(self):
        """Gets the count of this StreamingSwap.  # noqa: E501

        the amount of swap attempts so far  # noqa: E501

        :return: The count of this StreamingSwap.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this StreamingSwap.

        the amount of swap attempts so far  # noqa: E501

        :param count: The count of this StreamingSwap.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def last_height(self):
        """Gets the last_height of this StreamingSwap.  # noqa: E501

        the block height of the latest swap  # noqa: E501

        :return: The last_height of this StreamingSwap.  # noqa: E501
        :rtype: int
        """
        return self._last_height

    @last_height.setter
    def last_height(self, last_height):
        """Sets the last_height of this StreamingSwap.

        the block height of the latest swap  # noqa: E501

        :param last_height: The last_height of this StreamingSwap.  # noqa: E501
        :type: int
        """

        self._last_height = last_height

    @property
    def trade_target(self):
        """Gets the trade_target of this StreamingSwap.  # noqa: E501

        the total number of tokens the swapper wants to receive of the output asset  # noqa: E501

        :return: The trade_target of this StreamingSwap.  # noqa: E501
        :rtype: str
        """
        return self._trade_target

    @trade_target.setter
    def trade_target(self, trade_target):
        """Sets the trade_target of this StreamingSwap.

        the total number of tokens the swapper wants to receive of the output asset  # noqa: E501

        :param trade_target: The trade_target of this StreamingSwap.  # noqa: E501
        :type: str
        """
        if trade_target is None:
            raise ValueError("Invalid value for `trade_target`, must not be `None`")  # noqa: E501

        self._trade_target = trade_target

    @property
    def source_asset(self):
        """Gets the source_asset of this StreamingSwap.  # noqa: E501

        the asset to be swapped from  # noqa: E501

        :return: The source_asset of this StreamingSwap.  # noqa: E501
        :rtype: str
        """
        return self._source_asset

    @source_asset.setter
    def source_asset(self, source_asset):
        """Sets the source_asset of this StreamingSwap.

        the asset to be swapped from  # noqa: E501

        :param source_asset: The source_asset of this StreamingSwap.  # noqa: E501
        :type: str
        """

        self._source_asset = source_asset

    @property
    def target_asset(self):
        """Gets the target_asset of this StreamingSwap.  # noqa: E501

        the asset to be swapped to  # noqa: E501

        :return: The target_asset of this StreamingSwap.  # noqa: E501
        :rtype: str
        """
        return self._target_asset

    @target_asset.setter
    def target_asset(self, target_asset):
        """Sets the target_asset of this StreamingSwap.

        the asset to be swapped to  # noqa: E501

        :param target_asset: The target_asset of this StreamingSwap.  # noqa: E501
        :type: str
        """

        self._target_asset = target_asset

    @property
    def destination(self):
        """Gets the destination of this StreamingSwap.  # noqa: E501

        the destination address to receive the swap output  # noqa: E501

        :return: The destination of this StreamingSwap.  # noqa: E501
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this StreamingSwap.

        the destination address to receive the swap output  # noqa: E501

        :param destination: The destination of this StreamingSwap.  # noqa: E501
        :type: str
        """

        self._destination = destination

    @property
    def deposit(self):
        """Gets the deposit of this StreamingSwap.  # noqa: E501

        the number of input tokens the swapper has deposited  # noqa: E501

        :return: The deposit of this StreamingSwap.  # noqa: E501
        :rtype: str
        """
        return self._deposit

    @deposit.setter
    def deposit(self, deposit):
        """Sets the deposit of this StreamingSwap.

        the number of input tokens the swapper has deposited  # noqa: E501

        :param deposit: The deposit of this StreamingSwap.  # noqa: E501
        :type: str
        """
        if deposit is None:
            raise ValueError("Invalid value for `deposit`, must not be `None`")  # noqa: E501

        self._deposit = deposit

    @property
    def _in(self):
        """Gets the _in of this StreamingSwap.  # noqa: E501

        the amount of input tokens that have been swapped so far  # noqa: E501

        :return: The _in of this StreamingSwap.  # noqa: E501
        :rtype: str
        """
        return self.__in

    @_in.setter
    def _in(self, _in):
        """Sets the _in of this StreamingSwap.

        the amount of input tokens that have been swapped so far  # noqa: E501

        :param _in: The _in of this StreamingSwap.  # noqa: E501
        :type: str
        """
        if _in is None:
            raise ValueError("Invalid value for `_in`, must not be `None`")  # noqa: E501

        self.__in = _in

    @property
    def out(self):
        """Gets the out of this StreamingSwap.  # noqa: E501

        the amount of output tokens that have been swapped so far  # noqa: E501

        :return: The out of this StreamingSwap.  # noqa: E501
        :rtype: str
        """
        return self._out

    @out.setter
    def out(self, out):
        """Sets the out of this StreamingSwap.

        the amount of output tokens that have been swapped so far  # noqa: E501

        :param out: The out of this StreamingSwap.  # noqa: E501
        :type: str
        """
        if out is None:
            raise ValueError("Invalid value for `out`, must not be `None`")  # noqa: E501

        self._out = out

    @property
    def failed_swaps(self):
        """Gets the failed_swaps of this StreamingSwap.  # noqa: E501

        the list of swap indexes that failed  # noqa: E501

        :return: The failed_swaps of this StreamingSwap.  # noqa: E501
        :rtype: list[int]
        """
        return self._failed_swaps

    @failed_swaps.setter
    def failed_swaps(self, failed_swaps):
        """Sets the failed_swaps of this StreamingSwap.

        the list of swap indexes that failed  # noqa: E501

        :param failed_swaps: The failed_swaps of this StreamingSwap.  # noqa: E501
        :type: list[int]
        """

        self._failed_swaps = failed_swaps

    @property
    def failed_swap_reasons(self):
        """Gets the failed_swap_reasons of this StreamingSwap.  # noqa: E501

        the list of reasons that sub-swaps have failed  # noqa: E501

        :return: The failed_swap_reasons of this StreamingSwap.  # noqa: E501
        :rtype: list[str]
        """
        return self._failed_swap_reasons

    @failed_swap_reasons.setter
    def failed_swap_reasons(self, failed_swap_reasons):
        """Sets the failed_swap_reasons of this StreamingSwap.

        the list of reasons that sub-swaps have failed  # noqa: E501

        :param failed_swap_reasons: The failed_swap_reasons of this StreamingSwap.  # noqa: E501
        :type: list[str]
        """

        self._failed_swap_reasons = failed_swap_reasons

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StreamingSwap, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamingSwap):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class QueueResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'swap': 'int',
        'outbound': 'int',
        'internal': 'int',
        'scheduled_outbound_value': 'str',
        'scheduled_outbound_clout': 'str'
    }

    attribute_map = {
        'swap': 'swap',
        'outbound': 'outbound',
        'internal': 'internal',
        'scheduled_outbound_value': 'scheduled_outbound_value',
        'scheduled_outbound_clout': 'scheduled_outbound_clout'
    }

    def __init__(self, swap=None, outbound=None, internal=None, scheduled_outbound_value=None, scheduled_outbound_clout=None):  # noqa: E501
        """QueueResponse - a model defined in Swagger"""  # noqa: E501
        self._swap = None
        self._outbound = None
        self._internal = None
        self._scheduled_outbound_value = None
        self._scheduled_outbound_clout = None
        self.discriminator = None
        self.swap = swap
        self.outbound = outbound
        self.internal = internal
        self.scheduled_outbound_value = scheduled_outbound_value
        self.scheduled_outbound_clout = scheduled_outbound_clout

    @property
    def swap(self):
        """Gets the swap of this QueueResponse.  # noqa: E501


        :return: The swap of this QueueResponse.  # noqa: E501
        :rtype: int
        """
        return self._swap

    @swap.setter
    def swap(self, swap):
        """Sets the swap of this QueueResponse.


        :param swap: The swap of this QueueResponse.  # noqa: E501
        :type: int
        """
        if swap is None:
            raise ValueError("Invalid value for `swap`, must not be `None`")  # noqa: E501

        self._swap = swap

    @property
    def outbound(self):
        """Gets the outbound of this QueueResponse.  # noqa: E501

        number of signed outbound tx in the queue  # noqa: E501

        :return: The outbound of this QueueResponse.  # noqa: E501
        :rtype: int
        """
        return self._outbound

    @outbound.setter
    def outbound(self, outbound):
        """Sets the outbound of this QueueResponse.

        number of signed outbound tx in the queue  # noqa: E501

        :param outbound: The outbound of this QueueResponse.  # noqa: E501
        :type: int
        """
        if outbound is None:
            raise ValueError("Invalid value for `outbound`, must not be `None`")  # noqa: E501

        self._outbound = outbound

    @property
    def internal(self):
        """Gets the internal of this QueueResponse.  # noqa: E501


        :return: The internal of this QueueResponse.  # noqa: E501
        :rtype: int
        """
        return self._internal

    @internal.setter
    def internal(self, internal):
        """Sets the internal of this QueueResponse.


        :param internal: The internal of this QueueResponse.  # noqa: E501
        :type: int
        """
        if internal is None:
            raise ValueError("Invalid value for `internal`, must not be `None`")  # noqa: E501

        self._internal = internal

    @property
    def scheduled_outbound_value(self):
        """Gets the scheduled_outbound_value of this QueueResponse.  # noqa: E501

        scheduled outbound value in RUNE  # noqa: E501

        :return: The scheduled_outbound_value of this QueueResponse.  # noqa: E501
        :rtype: str
        """
        return self._scheduled_outbound_value

    @scheduled_outbound_value.setter
    def scheduled_outbound_value(self, scheduled_outbound_value):
        """Sets the scheduled_outbound_value of this QueueResponse.

        scheduled outbound value in RUNE  # noqa: E501

        :param scheduled_outbound_value: The scheduled_outbound_value of this QueueResponse.  # noqa: E501
        :type: str
        """
        if scheduled_outbound_value is None:
            raise ValueError("Invalid value for `scheduled_outbound_value`, must not be `None`")  # noqa: E501

        self._scheduled_outbound_value = scheduled_outbound_value

    @property
    def scheduled_outbound_clout(self):
        """Gets the scheduled_outbound_clout of this QueueResponse.  # noqa: E501

        scheduled outbound clout in RUNE  # noqa: E501

        :return: The scheduled_outbound_clout of this QueueResponse.  # noqa: E501
        :rtype: str
        """
        return self._scheduled_outbound_clout

    @scheduled_outbound_clout.setter
    def scheduled_outbound_clout(self, scheduled_outbound_clout):
        """Sets the scheduled_outbound_clout of this QueueResponse.

        scheduled outbound clout in RUNE  # noqa: E501

        :param scheduled_outbound_clout: The scheduled_outbound_clout of this QueueResponse.  # noqa: E501
        :type: str
        """
        if scheduled_outbound_clout is None:
            raise ValueError("Invalid value for `scheduled_outbound_clout`, must not be `None`")  # noqa: E501

        self._scheduled_outbound_clout = scheduled_outbound_clout

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(QueueResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueueResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class QuoteFees(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset': 'str',
        'affiliate': 'str',
        'outbound': 'str',
        'liquidity': 'str',
        'total': 'str',
        'slippage_bps': 'int',
        'total_bps': 'int'
    }

    attribute_map = {
        'asset': 'asset',
        'affiliate': 'affiliate',
        'outbound': 'outbound',
        'liquidity': 'liquidity',
        'total': 'total',
        'slippage_bps': 'slippage_bps',
        'total_bps': 'total_bps'
    }

    def __init__(self, asset=None, affiliate=None, outbound=None, liquidity=None, total=None, slippage_bps=None, total_bps=None):  # noqa: E501
        """QuoteFees - a model defined in Swagger"""  # noqa: E501
        self._asset = None
        self._affiliate = None
        self._outbound = None
        self._liquidity = None
        self._total = None
        self._slippage_bps = None
        self._total_bps = None
        self.discriminator = None
        self.asset = asset
        if affiliate is not None:
            self.affiliate = affiliate
        if outbound is not None:
            self.outbound = outbound
        self.liquidity = liquidity
        self.total = total
        self.slippage_bps = slippage_bps
        self.total_bps = total_bps

    @property
    def asset(self):
        """Gets the asset of this QuoteFees.  # noqa: E501

        the target asset used for all fees  # noqa: E501

        :return: The asset of this QuoteFees.  # noqa: E501
        :rtype: str
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """Sets the asset of this QuoteFees.

        the target asset used for all fees  # noqa: E501

        :param asset: The asset of this QuoteFees.  # noqa: E501
        :type: str
        """
        if asset is None:
            raise ValueError("Invalid value for `asset`, must not be `None`")  # noqa: E501

        self._asset = asset

    @property
    def affiliate(self):
        """Gets the affiliate of this QuoteFees.  # noqa: E501

        affiliate fee in the target asset  # noqa: E501

        :return: The affiliate of this QuoteFees.  # noqa: E501
        :rtype: str
        """
        return self._affiliate

    @affiliate.setter
    def affiliate(self, affiliate):
        """Sets the affiliate of this QuoteFees.

        affiliate fee in the target asset  # noqa: E501

        :param affiliate: The affiliate of this QuoteFees.  # noqa: E501
        :type: str
        """

        self._affiliate = affiliate

    @property
    def outbound(self):
        """Gets the outbound of this QuoteFees.  # noqa: E501

        outbound fee in the target asset  # noqa: E501

        :return: The outbound of this QuoteFees.  # noqa: E501
        :rtype: str
        """
        return self._outbound

    @outbound.setter
    def outbound(self, outbound):
        """Sets the outbound of this QuoteFees.

        outbound fee in the target asset  # noqa: E501

        :param outbound: The outbound of this QuoteFees.  # noqa: E501
        :type: str
        """

        self._outbound = outbound

    @property
    def liquidity(self):
        """Gets the liquidity of this QuoteFees.  # noqa: E501

        liquidity fees paid to pools in the target asset  # noqa: E501

        :return: The liquidity of this QuoteFees.  # noqa: E501
        :rtype: str
        """
        return self._liquidity

    @liquidity.setter
    def liquidity(self, liquidity):
        """Sets the liquidity of this QuoteFees.

        liquidity fees paid to pools in the target asset  # noqa: E501

        :param liquidity: The liquidity of this QuoteFees.  # noqa: E501
        :type: str
        """
        if liquidity is None:
            raise ValueError("Invalid value for `liquidity`, must not be `None`")  # noqa: E501

        self._liquidity = liquidity

    @property
    def total(self):
        """Gets the total of this QuoteFees.  # noqa: E501

        total fees in the target asset  # noqa: E501

        :return: The total of this QuoteFees.  # noqa: E501
        :rtype: str
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this QuoteFees.

        total fees in the target asset  # noqa: E501

        :param total: The total of this QuoteFees.  # noqa: E501
        :type: str
        """
        if total is None:
            raise ValueError("Invalid value for `total`, must not be `None`")  # noqa: E501

        self._total = total

    @property
    def slippage_bps(self):
        """Gets the slippage_bps of this QuoteFees.  # noqa: E501

        the swap slippage in basis points  # noqa: E501

        :return: The slippage_bps of this QuoteFees.  # noqa: E501
        :rtype: int
        """
        return self._slippage_bps

    @slippage_bps.setter
    def slippage_bps(self, slippage_bps):
        """Sets the slippage_bps of this QuoteFees.

        the swap slippage in basis points  # noqa: E501

        :param slippage_bps: The slippage_bps of this QuoteFees.  # noqa: E501
        :type: int
        """
        if slippage_bps is None:
            raise ValueError("Invalid value for `slippage_bps`, must not be `None`")  # noqa: E501

        self._slippage_bps = slippage_bps

    @property
    def total_bps(self):
        """Gets the total_bps of this QuoteFees.  # noqa: E501

        total basis points in fees relative to amount out  # noqa: E501

        :return: The total_bps of this QuoteFees.  # noqa: E501
        :rtype: int
        """
        return self._total_bps

    @total_bps.setter
    def total_bps(self, total_bps):
        """Sets the total_bps of this QuoteFees.

        total basis points in fees relative to amount out  # noqa: E501

        :param total_bps: The total_bps of this QuoteFees.  # noqa: E501
        :type: int
        """
        if total_bps is None:
            raise ValueError("Invalid value for `total_bps`, must not be `None`")  # noqa: E501

        self._total_bps = total_bps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(QuoteFees, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QuoteFees):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
